[gimp] app: gimp_gegl_convolve() rename parameter "matrix" to "kernel"



commit 2ea74df523819ddcf4844c0e37a450f40bb3e7ed
Author: Michael Natterer <mitch gimp org>
Date:   Wed Apr 4 14:05:56 2012 +0200

    app: gimp_gegl_convolve() rename parameter "matrix" to "kernel"

 app/gegl/gimp-gegl-loops.c |   12 ++++++------
 app/gegl/gimp-gegl-loops.h |    4 ++--
 2 files changed, 8 insertions(+), 8 deletions(-)
---
diff --git a/app/gegl/gimp-gegl-loops.h b/app/gegl/gimp-gegl-loops.h
index 866d2a0..525c799 100644
--- a/app/gegl/gimp-gegl-loops.h
+++ b/app/gegl/gimp-gegl-loops.h
@@ -29,8 +29,8 @@ void   gimp_gegl_convolve  (GeglBuffer          *src_buffer,
                             const GeglRectangle *src_rect,
                             GeglBuffer          *dest_buffer,
                             const GeglRectangle *dest_rect,
-                            const gfloat        *matrix,
-                            gint                 size,
+                            const gfloat        *kernel,
+                            gint                 kernel_size,
                             gdouble              divisor,
                             GimpConvolutionType  mode,
                             gboolean             alpha_weighting);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/app/gegl/gimp-gegl-loops.c b/app/gegl/gimp-gegl-loops.c
index 38298da..84d79ac 100644
--- a/app/gegl/gimp-gegl-loops.c
+++ b/app/gegl/gimp-gegl-loops.c
@@ -34,8 +34,8 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
                     const GeglRectangle *src_rect,
                     GeglBuffer          *dest_buffer,
                     const GeglRectangle *dest_rect,
-                    const gfloat        *matrix,
-                    gint                 size,
+                    const gfloat        *kernel,
+                    gint                 kernel_size,
                     gdouble              divisor,
                     GimpConvolutionType  mode,
                     gboolean             alpha_weighting)
@@ -64,7 +64,7 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
 
   while (gegl_buffer_iterator_next (iter))
     {
       /*  Convolve the src image using the convolution matrix, writing
        *  to dest Convolve is not tile-enabled--use accordingly
        */
       const guchar *src       = iter->data[0];
@@ -72,7 +72,7 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
       const gint    bytes     = src_bpp;
       const gint    a_byte    = bytes - 1;
       const gint    rowstride = src_bpp * src_roi->width;
-      const gint    margin    = size / 2;
+      const gint    margin    = kernel_size / 2;
       const gint    x1        = src_roi->x;
       const gint    y1        = src_roi->y;
       const gint    x2        = src_roi->x + src_roi->width  - 1;
@@ -99,7 +99,7 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
             {
               for (x = 0; x < dest_roi->width; x++)
                 {
-                  const gfloat *m                = matrix;
+                  const gfloat *m                = kernel;
                   gdouble       total[4]         = { 0.0, 0.0, 0.0, 0.0 };
                   gdouble       weighted_divisor = 0.0;
                   gint          i, j, b;
@@ -153,7 +153,7 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
             {
               for (x = 0; x < dest_roi->width; x++)
                 {
-                  const gfloat *m        = matrix;
+                  const gfloat *m        = kernel;
                   gdouble       total[4] = { 0.0, 0.0, 0.0, 0.0 };
                   gint          i, j, b;
 
@@ -64,7 +64,7 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
   while (gegl_buffer_iterator_next (iter))
     {
-      /*  Convolve the src image using the convolution matrix, writing
+      /*  Convolve the src image using the convolution kernel, writing
        *  to dest Convolve is not tile-enabled--use accordingly
        */